@@ -13,5 +13,7 @@ pub use yggdrasil_shared::DiagnosticLevel;
 pub extern crate git2;
 #[cfg(feature = "globset")]
 pub extern crate globset;
+#[cfg(feature = "nom")]
+pub extern crate nom;
 #[cfg(feature = "num")]
 pub extern crate num;
